==> eslint-plugin-node-1.2.1.tgz: package/lib/util/get-package-json.js <==
/**
 * @author Toru Nagashima
 * @copyright 2015 Toru Nagashima. All rights reserved.
 * See LICENSE file in root directory for full license.
 */

"use strict";

//------------------------------------------------------------------------------
// Requirements
//------------------------------------------------------------------------------

var fs = require("fs");
var path = require("path");
var Cache = require("./cache");

//------------------------------------------------------------------------------
// Helpers
//------------------------------------------------------------------------------

var cache = new Cache();

/**
 * Reads the `package.json` data in a given path.
 *
 * Don't cache the data.
 *
 * @param {string} dir - The path to a directory to read.
 * @returns {object|null} The read `package.json` data, or null.
 */
function readPackageJson(dir) {
    var filePath = path.join(dir, "package.json");
    try {
        var text = fs.readFileSync(filePath, "utf8");
        var data = JSON.parse(text);

        if (typeof data === "object" && data !== null) {
            data.filePath = filePath;
            return data;
        }
    }
    catch (_err) {
        // do nothing.
    }

    return null;
}

//------------------------------------------------------------------------------
// Public Interface
//------------------------------------------------------------------------------

/**
 * Gets a `package.json` data.
 * The data is cached if found, then it's used after.
 *
 * @param {string} startPath - A file path to lookup.
 * @returns {object|null} A found `package.json` data or `null`.
 *      This object have additional property `filePath`.
 */
module.exports = function getPackageJson(startPath) {
    var startDir = path.dirname(path.resolve(startPath));
    var dir = startDir;
    var prevDir, data;

    do {
        data = cache.get(dir);
        if (data) {
            if (dir !== startDir) {
                cache.put(startDir, data);
            }
            return data;
        }

        data = readPackageJson(dir);
        if (data) {
            cache.put(dir, data);
            cache.put(startDir, data);
            return data;
        }

        // Go to next.
        prevDir = dir;
        dir = path.resolve(dir, "..");
    }
    while (dir !== prevDir);

    cache.put(startDir, null);
    return null;
};

==> eslint-plugin-node-2.1.2.tgz: package/lib/util/get-package-json.js <==
/**
 * @author Toru Nagashima
 * @copyright 2015 Toru Nagashima. All rights reserved.
 * See LICENSE file in root directory for full license.
 */

"use strict"

//------------------------------------------------------------------------------
// Requirements
//------------------------------------------------------------------------------

var fs = require("fs")
var path = require("path")
var Cache = require("./cache")

//------------------------------------------------------------------------------
// Helpers
//------------------------------------------------------------------------------

var cache = new Cache()

/**
 * Reads the `package.json` data in a given path.
 *
 * Don't cache the data.
 *
 * @param {string} dir - The path to a directory to read.
 * @returns {object|null} The read `package.json` data, or null.
 */
function readPackageJson(dir) {
    var filePath = path.join(dir, "package.json")
    try {
        var text = fs.readFileSync(filePath, "utf8")
        var data = JSON.parse(text)

        if (typeof data === "object" && data !== null) {
            data.filePath = filePath
            return data
        }
    }
    catch (_err) {
        // do nothing.
    }

    return null
}

//------------------------------------------------------------------------------
// Public Interface
//------------------------------------------------------------------------------

/**
 * Gets a `package.json` data.
 * The data is cached if found, then it's used after.
 *
 * @param {string} startPath - A file path to lookup.
 * @returns {object|null} A found `package.json` data or `null`.
 *      This object have additional property `filePath`.
 */
module.exports = function getPackageJson(startPath) {
    var startDir = path.dirname(path.resolve(startPath))
    var dir = startDir
    var prevDir = ""
    var data = null

    do {
        data = cache.get(dir)
        if (data) {
            if (dir !== startDir) {
                cache.put(startDir, data)
            }
            return data
        }

        data = readPackageJson(dir)
        if (data) {
            cache.put(dir, data)
            cache.put(startDir, data)
            return data
        }

        // Go to next.
        prevDir = dir
        dir = path.resolve(dir, "..")
    }
    while (dir !== prevDir)

    cache.put(startDir, null)
    return null
}
